Name:           mingw-crossreport
Version:        201406
Release:        %mkrel 5
Summary:        Analysis tool to help cross-compilation to Windows

License:        GPLv2+
Group:          Development/Other
URL:            https://fedoraproject.org/wiki/MinGW
Source0:        crossreport.pl
Source1:        README
Source2:        COPYING
Source3:        crossreport.db.xz
Source4:        update-crossreport-db.pl

BuildArch:      noarch

BuildRequires:  perl
BuildRequires:  perl-podlators

BuildRequires:  xz

# For nm and c++filt.
Requires:       binutils


%description
CrossReport is a tool to help you analyze the APIs used by a compiled
Linux program, in order to work out the effort required to
cross-compile that program for Windows, using the Fedora MinGW
cross-compiler.

The simplest way to use it is to point it at an existing Linux binary,
and then read the generated report.

What it does in more detail: It looks at the libraries and API calls
used by the Linux binary, and compares them to the libraries and API
calls that we currently support under the Fedora MinGW cross-compiler.
It then works out what is missing, and produces a report suggesting
the amount of work that needs to be done to port the program.  For
example, whether whole libraries need to be ported first, and/or how
to substitute individual calls to work on Windows.


%package -n mingw32-crossreport
Summary:        Analysis tool to help cross-compilation to Windows

%description -n mingw32-crossreport
CrossReport is a tool to help you analyze the APIs used by a compiled
Linux program, in order to work out the effort required to
cross-compile that program for Windows, using the Fedora MinGW
cross-compiler.

The simplest way to use it is to point it at an existing Linux binary,
and then read the generated report.

What it does in more detail: It looks at the libraries and API calls
used by the Linux binary, and compares them to the libraries and API
calls that we currently support under the Fedora MinGW cross-compiler.
It then works out what is missing, and produces a report suggesting
the amount of work that needs to be done to port the program.  For
example, whether whole libraries need to be ported first, and/or how
to substitute individual calls to work on Windows.


%prep
# empty


%build
# empty


%install
mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -m 0755 %{SOURCE0} $RPM_BUILD_ROOT%{_bindir}/mingw32-crossreport

# Install the database.
mkdir -p $RPM_BUILD_ROOT%{_datadir}/crossreport
xzcat %{SOURCE3} > $RPM_BUILD_ROOT%{_datadir}/crossreport/crossreport.db
chmod 0644 $RPM_BUILD_ROOT%{_datadir}/crossreport/crossreport.db

# Install documentation (manually).
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
install -m 0644 %{SOURCE1} %{SOURCE2} $RPM_BUILD_ROOT%{_docdir}/%{name}

# Build the manpage from the source.
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
pod2man -c "CrossReport" -r "%{name}-%{version}" %{SOURCE0} \
  > $RPM_BUILD_ROOT%{_mandir}/man1/mingw32-crossreport.1


%files -n mingw32-crossreport
%doc %{_docdir}/%{name}/COPYING
%doc %{_docdir}/%{name}/README
%{_bindir}/mingw32-crossreport
%{_mandir}/man1/mingw32-crossreport.1*
%{_datadir}/crossreport/




%changelog
* Fri Jun 27 2025 umeabot <umeabot> 201406-5.mga10
+ Revision: 2207365
- Mageia 10 Mass Rebuild

* Tue Mar 22 2022 umeabot <umeabot> 201406-4.mga9
+ Revision: 1816830
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 201406-3.mga8
+ Revision: 1492001
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 201406-2.mga7
+ Revision: 1264266
- Mageia 7 Mass Rebuild

* Wed May 11 2016 tv <tv> 201406-1.mga6
+ Revision: 1012439
- new release

* Sat Feb 06 2016 umeabot <umeabot> 201308-5.mga6
+ Revision: 940201
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 201308-4.mga5
+ Revision: 744891
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 201308-3.mga5
+ Revision: 682416
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 201308-2.mga4
+ Revision: 536159
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 201308-1.mga4
+ Revision: 483487
- imported package mingw-crossreport


* Tue Aug  6 2013 Richard W.M. Jones <rjones@redhat.com> - 201308-1
- Fix update-crossreport-db.pl so it ignores 'R' (read-only data) symbols.
- Update the database against all mingw32-* packages in Fedora 19.
- xz-compress the database so it doesn't take up so much space.
- Change the versioning system so it includes the month that the
  database was last updated.  This is more informative.

* Tue Aug  6 2013 Richard W.M. Jones <rjones@redhat.com> - 8-8
- Unversioned docdir on F20 (RHBZ#993866).

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jul 18 2013 Petr Pisar <ppisar@redhat.com> - 8-6
- Perl 5.18 rebuild

* Thu Apr  4 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 8-5
- Added BR: perl-podlators for Fedora 19 and above

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Mar 07 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 8-2
- Renamed the source package to mingw-crossreport (RHBZ #800854)

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 8-1
- Made the package compatible with the mingw-w64 toolchain
- Dropped unneeded RPM tags

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 30 2010 Richard W.M. Jones <rjones@redhat.com> - 7-1
- Update database.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 13 2009 Richard W.M. Jones <rjones@redhat.com> - 6-1
- Change to use Berkeley DB for storage.

* Fri Feb 13 2009 Richard W.M. Jones <rjones@redhat.com> - 5-1
- Requires binutils, for nm and c++filt (thanks Richard Hughes).

* Fri Feb 13 2009 Richard W.M. Jones <rjones@redhat.com> - 4-1
- Include the update script.

* Wed Feb 11 2009 Richard W.M. Jones <rjones@redhat.com> - 3-1
- Initial RPM release.
